@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, timezone
 
 
 def format_timestamp(ts):
@@ -6,6 +6,6 @@ def format_timestamp(ts):
         return None
 
     if isinstance(ts, int):
-        ts = datetime.fromtimestamp(ts)
+        ts = datetime.fromtimestamp(ts, tz=timezone.utc)
 
     return ts.strftime('%Y-%m-%dT%H:%M:%SZ')
\ No newline at end of file
